==> qt4-x11_4.6.2.orig.tar.gz: qt-everywhere-opensource-src-4.6.2/src/corelib/io/qfilesystemwatcher_symbian_p.h <==
/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the QtCore module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial Usage
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QFILESYSTEMWATCHER_SYMBIAN_P_H
#define QFILESYSTEMWATCHER_SYMBIAN_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include "qfilesystemwatcher_p.h"

#ifndef QT_NO_FILESYSTEMWATCHER

#include "qhash.h"
#include "qmutex.h"
#include "qwaitcondition.h"

#include <e32base.h>
#include <f32file.h>

QT_BEGIN_NAMESPACE

class QSymbianFileSystemWatcherEngine;

class QNotifyChangeEvent : public CActive
{
public:
    QNotifyChangeEvent(RFs &fsSession, const TDesC &file, QSymbianFileSystemWatcherEngine *engine,
                       bool aIsDir, TInt aPriority = EPriorityStandard);
    ~QNotifyChangeEvent();

    bool isDir;

private:
    void RunL();
    void DoCancel();

    RFs &fsSession;
    TPath watchedPath;
    QSymbianFileSystemWatcherEngine *engine;

    int failureCount;
};

class QSymbianFileSystemWatcherEngine : public QFileSystemWatcherEngine
{
    Q_OBJECT

public:
    QSymbianFileSystemWatcherEngine();
    ~QSymbianFileSystemWatcherEngine();

    QStringList addPaths(const QStringList &paths, QStringList *files, QStringList *directories);
    QStringList removePaths(const QStringList &paths, QStringList *files,
                            QStringList *directories);

    void stop();

protected:
    void run();

public Q_SLOTS:
    void addNativeListener(const QString &directoryPath);
    void removeNativeListener();

private:
    friend class QNotifyChangeEvent;
    void emitPathChanged(QNotifyChangeEvent *e);

    bool startWatcher();

    QHash<QNotifyChangeEvent*, QString> activeObjectToPath;
    QMutex mutex;
    QWaitCondition syncCondition;
    int errorCode;
    bool watcherStarted;
    QNotifyChangeEvent *currentEvent;
};

#endif // QT_NO_FILESYSTEMWATCHER

QT_END_NAMESPACE

#endif // QFILESYSTEMWATCHER_WIN_P_H

==> qt4-x11_4.7.0.orig.tar.gz: qt-everywhere-opensource-src-4.7.0/src/corelib/io/qfilesystemwatcher_symbian_p.h <==
/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the QtCore module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial Usage
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QFILESYSTEMWATCHER_SYMBIAN_P_H
#define QFILESYSTEMWATCHER_SYMBIAN_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include "qfilesystemwatcher_p.h"

#ifndef QT_NO_FILESYSTEMWATCHER

#include "qhash.h"
#include "qmutex.h"
#include "qwaitcondition.h"

#include <e32base.h>
#include <f32file.h>

QT_BEGIN_NAMESPACE

class QSymbianFileSystemWatcherEngine;

class QNotifyChangeEvent : public CActive
{
public:
    QNotifyChangeEvent(RFs &fsSession, const TDesC &file, QSymbianFileSystemWatcherEngine *engine,
                       bool aIsDir, TInt aPriority = EPriorityStandard);
    ~QNotifyChangeEvent();

    bool isDir;

private:
    void RunL();
    void DoCancel();

    RFs &fsSession;
    TPath watchedPath;
    QSymbianFileSystemWatcherEngine *engine;

    int failureCount;
};

class QSymbianFileSystemWatcherEngine : public QFileSystemWatcherEngine
{
    Q_OBJECT

public:
    QSymbianFileSystemWatcherEngine();
    ~QSymbianFileSystemWatcherEngine();

    QStringList addPaths(const QStringList &paths, QStringList *files, QStringList *directories);
    QStringList removePaths(const QStringList &paths, QStringList *files,
                            QStringList *directories);

    void stop();

protected:
    void run();

public Q_SLOTS:
    void addNativeListener(const QString &directoryPath);
    void removeNativeListener();

private:
    friend class QNotifyChangeEvent;
    void emitPathChanged(QNotifyChangeEvent *e);

    void startWatcher();

    QHash<QNotifyChangeEvent*, QString> activeObjectToPath;
    QMutex mutex;
    QWaitCondition syncCondition;
    bool watcherStarted;
    QNotifyChangeEvent *currentAddEvent;
    QNotifyChangeEvent *currentRemoveEvent;
};

#endif // QT_NO_FILESYSTEMWATCHER

QT_END_NAMESPACE

#endif // QFILESYSTEMWATCHER_WIN_P_H
